@@ -1,4 +1,4 @@
-__all__ = ["Descriptor", "Typed", "Unsigned", "MaxSized",
+__all__ = ["Descriptor", "Typed", "Unsigned", "MaxSizedIterable",
            "Integer", "Float", "String", "Sequence"]
 
 from ._descriptor import Descriptor
